@@ -1,13 +1,8 @@
-#ifndef __ARRAY_H__
-#define __ARRAY_H__
-
-#include "config.h"
-#include "vm/jni.h"
+#include <config.h>
+#include <jni.h>
 
 JNIEXPORT jint JNICALL Java_java_lang_reflect_Array_getLength
   (JNIEnv * env, jclass thisClass, jobject arr);
 
 JNIEXPORT jobject JNICALL Java_java_lang_reflect_Array_createObjectArray
     (JNIEnv * env, jclass thisClass, jclass arrayType, jint arrayLength);
-
-#endif
