@@ -1,7 +1,2 @@
-#ifndef __CONSTRUCTOR_H__
-#define __CONSTRUCTOR_H__
-
 jobject java_lang_reflect_Constructor_constructNative(JNIEnv* env, jobject clazz, jobjectArray args,jclass theclass, jint slot);
 jint java_lang_reflect_Constructor_getModifiers(JNIEnv* env, jclass clazz);
-
-#endif
