@@ -3,9 +3,7 @@
  *
  */
 
-#include "vm/jni.h"
-
-// FIXME - delete this file ...
+#include "jni.h"
 
 //void java_lang_Thread_yield(JNIEnv* env, jobject obj);
 /*void java_lang_Thread_sleep(JNIEnv* env, jobject obj, jlong millis, jint nanos);
@@ -23,5 +21,5 @@ void java_lang_Thread__initC(JNIEnv* env, jobject obj);
 void java_lang_Thread__link(JNIEnv* env, jobject obj);
 void java_lang_Thread__createJNIData(JNIEnv* env, jobject obj);
 
-  
+
 */
