@@ -1,32 +1,32 @@
-#include "config.h"
+#include <config.h>
 /*
  * native stuff for java.lang.UnixProcess
  *
  */
 
-#include <sys/types.h>
-#include <sys/wait.h>
+ #include <sys/types.h>
+ #include <sys/wait.h>
        
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
-#include "vm/jni.h"
+#include "jni.h"
 
 #ifdef DLOPEN
-#include <dlfcn.h>
+  #include <dlfcn.h>
 #endif
 
+#include <assert.h>
 
 #ifdef DEBUG
 #include <stdio.h>
 #endif
 
-#include "vm/jni.h"
+#include "jni.h"
 #ifdef PERSIST
-#include "vm/rpot.h"
+#include "rpot.h"
 #endif
 
-
 /* Wait for the process to finish */
 
 jint java_lang_UnixProcess_waitFor(
