@@ -2,12 +2,11 @@
 /*
  * VMObject.h
  *
+ * 
+ *
  */
 
-#ifndef __VMOBJECT_H__
-#define _VMOBJECT_H__
-
-#include "vm/jni.h"
+#include "jni.h"
 
 void java_lang_VMObject_notify(JNIEnv* env,jobject o, jobject obj);
 void java_lang_VMObject_notifyAll(JNIEnv* env, jobject o, jobject obj);
@@ -26,5 +25,3 @@ jobject java_lang_VMObject_clone
   jobject obj
 );
 
-#endif
-
