@@ -1,6 +1,3 @@
-#ifndef __PSTORE_H__
-#define __PSTORE_H__
-
 void plava_PStore_stabiliseAll(JNIEnv* env, jobject obj);
 jobject plava_PStore_nativeOpenStore(JNIEnv* env, jstring name);
 jobject plava_PStore_nativeNewStore(JNIEnv* env, jstring name);
@@ -8,4 +5,3 @@ void plava_PStore_nativeCloseStore(JNIEnv* env, jobject obj);
 jobject plava_PStore_nativeGetRootObject(JNIEnv* env);
 void plava_PStore_nativeSetRootObject(JNIEnv* env, jobject);
 
-#endif
