@@ -1,4 +1,4 @@
-#include "config.h"
+#include <config.h> 
 /* 
  * @doc MODULE 
  * @module disass.c | 
@@ -12,11 +12,10 @@
 #include <stdio.h> 
 #endif
 
-#include "vm/stdtypes.h" 
-#include "vm/opcodes.h" 
+#include "stdtypes.h" 
+#include "opcodes.h" 
  
-#include "vm/global.h"
-#include "vm/interp.h"
+#include "global.h" 
  
 static char* pszHex1Byte = "\t0x%02x "; 
 static char* pszHex2Byte = "\t0x%04x "; 
@@ -48,9 +47,9 @@ static char* ppszOpCodeNames[] =
   "dconst_1", 
   "bipush", 
   "sipush", 
-  "ldc", 
-  "ldc_w", 
-  "ldc2_w", 
+  "ldc1", 
+  "ldc2", 
+  "ldc2w", 
   "iload", 
   "lload", 
   "fload", 
@@ -387,19 +386,19 @@ int DISASS_PrintInstruction
       iNumBytes = 3; 
       break; 
     } 
-    case ldc: 
+    case ldc1: 
     { 
       eprintf( pszHex1Byte, pbInstr[1]); 
       iNumBytes = 2; 
       break; 
     } 
-    case ldc_w: 
+    case ldc2: 
     { 
       eprintf( pszHex2Byte, pbInstr[1] * 256 + pbInstr[2]); 
       iNumBytes = 3; 
       break; 
     } 
-    case ldc2_w: 
+    case ldc2w: 
     { 
       eprintf( pszHex2Byte, pbInstr[1] * 256 + pbInstr[2]); 
       iNumBytes = 3; 
@@ -1628,6 +1627,7 @@ int DISASS_PrintInstruction
     default: 
     { 
       eprintf("Unknown assembler instruction: opcode %d\n", pbInstr[0]); 
+      /*###exit(1);*/ 
     } 
   } 
  
