@@ -29,7 +29,7 @@
 #ifndef __DISASS_H__
 #define __DISASS_H__
 
-#include "vm/stdtypes.h"
+#include "stdtypes.h"
 #include <stdio.h>
 
 int DISASS_PrintInstruction(byte* instr, byte* codestart);
