@@ -1,9 +1,4 @@
-#ifndef __OLDHEAP_H__
-#define __OLDHEAP_H__
-
 int OLDHEAP_Init(tAllocatorHeap* heap);
 int OLDHEAP_ISHANDLE(tAllocatorHeap* heap, tOBREF h);
 int OLDHEAP_SweepAndCompact(tAllocatorHeap* heap);
 int OLDHEAP_TestBitfield(tAllocatorHeap* heap);
-
-#endif
