@@ -1,6 +1,3 @@
-#ifndef __TLH_H__
-#define __TLH_H__
-
 /* Structures defining a thread-local-heap */
 
 typedef struct tthreadlocalheap {
@@ -10,5 +7,3 @@ typedef struct tthreadlocalheap {
   int32 words[375];		//Number of words reserved for actual object allocation
 
 } tThreadLocalHeap;
-
-#endif
