@@ -1,12 +1,13 @@
 /* Routines to manage the young heap */
 
-#include "config.h"
+#include <config.h>
+#include <assert.h>
 
 
-#include "vm/garbage/public_methods.h"
-#include "vm/garbage/bitfield.h"
-#include "vm/garbage/tlh.h"
-#include "vm/garbage/youngheap.h"
+#include "public_methods.h"
+#include "bitfield.h"
+#include "tlh.h"
+#include "youngheap.h"
 
 int YOUNGHEAP_Init(tAllocatorHeap* heap)
 {
