@@ -1,7 +1,2 @@
-#ifndef __YOUNGHEAP_H__
-#define __YOUNGHEAP_H__
-
 int YOUNGHEAP_Init(tAllocatorHeap* heap);
 int YOUNGHEAP_ISHANDLE(tAllocatorHeap* heap, tOBREF h);
-
-#endif
