@@ -1,10 +1,5 @@
-#ifndef __METHOD_STACKS_H__
-#define __METHOD_STACKS_H__
-
 tStackFrame* InitialStackFrame(tMethod*,tOBREF,int32*,tAllocatorHeap*);
 tStackFrame* InitialStackFrameHelper(  tMethod* pstNewMethod,  /* @parm Pointer to the method to use */  tOBREF pstNewObject,  /* @parm Pointer to the current object */  int32* pi32Args,         /* @parm Pointer to method arguments */ tAllocatorHeap*, byte isOrphan);
 tStackFrame* PushStackFrame(tMethod*,tOBREF,tStackFrame*);
 tStackFrame* PushNativeStackFrame(tMethod*, tOBREF, tStackFrame*);
 tStackFrame* PopStackFrame(tStackFrame*);
-
-#endif
