@@ -1,16 +1,16 @@
-#include "config.h"
-
+#ifdef USE_ZIP_CLASSLOADER
 /* unzip.c -- IO on .zip files using zlib 
    Version 0.15 beta, Mar 19th, 1998,
 
    Read unzip.h for more info
 */
 
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include "zlib.h"
-#include "vm/lib/minizip/unzip.h"
+#include "unzip.h"
 
 #ifdef STDC
 #  include <stddef.h>
@@ -1294,3 +1294,7 @@ extern int ZEXPORT unzGetGlobalComment (file, szComment, uSizeBuf)
 	return (int)uReadThis;
 }
 
+
+
+
+#endif //#ifdef USE_ZIP_CLASSLOADER
