@@ -1,6 +1,3 @@
-#ifndef __LOADING_ERRORS_H__
-#define __LOADING_ERRORS_H__
-
 enum tloading_error {
   LOADING_ERROR_NO_FILE = 1,
   LOADING_ERROR_BAD_MAGIC,
@@ -11,11 +8,7 @@ enum tloading_error {
   LOADING_ERROR_BAD_ATTRIBUTES,
   LOADING_ERROR_OUT_OF_MEMORY,
   LOADING_ERROR_NO_CLASSPATH,
-  LOADING_ERROR_BAD_CLASS_NAME,
-  LOADING_ERROR_NOT_ZIPFILE,
-  LOADING_ERROR_ZIP_ERROR,
+  LOADING_ERROR_BAD_CLASS_NAME
 };
 
-const char* loadingErrorMessage(uint32 errcode);
-
-#endif
+void printLoadingError(uint32 errcode);
