@@ -18,23 +18,17 @@
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __LOCKS_H__
-#define __LOCKS_H__
-
 #include <pthread.h>
-#include <signal.h>
-
-#include "vm/interp.h"
-#include "thread.h"
+#include "interp.h"
 
 /* Structure for the fat lock */
 
 typedef struct tfatlock {
-  tMutex* lock;
-  threadId_t owner;
-  int recursion_count; //Number of times this lock has been locked
-                       //by the owning thread
-  
+
+tMutex* lock;
+int owner;
+int recursion_count; //Number of times this lock has been locked be the owning thread
+
 } tFatlock;
 
 
@@ -43,9 +37,6 @@ int THREAD_NotifyAll(JNIEnv* env,tOBREF);
 int THREAD_Notify (JNIEnv* env, tOBREF pstObject, int notify_all);
 
 int THREAD_WaitOnObject(JNIEnv*, tOBREF, jlong);
-void THREAD_Interrupt(JNIEnv*, tThreadNode*);
 
-void THREAD_SynchroniseExit (tOBREF pstObject  /* @parm Object to release */);
-void THREAD_SynchroniseEnter (tOBREF pstObject /* @parm Object to lock */);
-
-#endif
+void THREAD_SynchroniseExit (tOBREF pstObject	/* @parm Object to release */  );
+void THREAD_SynchroniseEnter (tOBREF pstObject	/* @parm Object to lock */ );
