@@ -8,6 +8,5 @@
 {"java/lang/Runtime", "traceMethodCalls", "(Z)V", (void*) Java_java_lang_Runtime_traceMethodCalls }, 
 {"java/lang/Runtime", "nativeLoad", "(Ljava/lang/String;)I", (void*) Java_java_lang_Runtime_nativeLoad }, 
 {"java/lang/Runtime", "nativeGetLibname", "(Ljava/lang/String;Ljava/lang/String;)Ljava/lang/String;", (void*) Java_java_lang_Runtime_nativeGetLibname }, 
-{"java/lang/Runtime", "execInternal", "([Ljava/lang/String;[Ljava/lang/String;Ljava/io/File;)Ljava/lang/Process;", (void*) Java_java_lang_Runtime_execInternal }, 
+{"java/lang/Runtime", "execInternal", "([Ljava/lang/String;[Ljava/lang/String;)Ljava/lang/Process;", (void*) Java_java_lang_Runtime_execInternal }, 
 {"java/lang/Runtime", "getLibraryPath", "()Ljava/lang/String;", (void*) Java_java_lang_Runtime_getLibraryPath },
-{"java/lang/Runtime", "insertSystemProperties", "(Ljava/util/Properties;)V", (void*) Java_java_lang_Runtime_insertSystemProperties},
