@@ -10,7 +10,7 @@
 #ifndef __NATIVES_H__
 #define __NATIVES_H__
 
-#include "vm/classfil.h"
+#include "classfil.h"
 
 typedef struct 
 { 
@@ -20,6 +20,6 @@ typedef struct
   void* pFunction;       /* @field Function pointer to the native method */ 
 } tNewNativeLookup; 
 
-void NATIVES_InitNatives(tClassLoaderTuple* pstClass, int32 isSafe);
+void NATIVES_InitNatives(tClassLoaderTuple* pstClass);
 
 #endif
