@@ -1,6 +1,3 @@
-#ifndef __STRUCT_TEXCEPTION_H__
-#define __STRUCT_TEXCEPTION_H__
-
 /*
  * @doc TYPE
  * @struct
@@ -11,13 +8,11 @@
 
 struct texceptioninfo
 {
-#ifdef CLASSPERSIST
+  #ifdef CLASSPERSIST
   PID pid;
-#endif
+  #endif
   uint16  u16StartPC;   /* @field Start PC of exception's effect */
   uint16  u16EndPC;     /* @field End PC of exception's effect */
   uint16  u16HandlerPC; /* @field PC of exception's handling code */
   tClassLoaderTuple* pstCatchType; /* @field Type of exception that this clause catches */
 };
-
-#endif
