@@ -1,6 +1,3 @@
-#ifndef __TEASME_PRINT_H__
-#define __TEASME_PRINT_H__
-
 #ifdef KISSME_LINUX_KERNEL
 
 #ifdef USE_PRINTK
@@ -28,5 +25,3 @@
 
 #endif
 #endif
-
-#endif
