@@ -10,8 +10,8 @@
 #ifndef __THREADEX_H__
 #define __THREADEX_H__
 
-#include "vm/interp.h"
-#include "vm/jni.h"
+#include "interp.h"
+#include "jni.h"
 
 void THREAD_Destroy(tOBREF);
 void THREAD_ForceThreadSwitch(tOBREF);
