@@ -1,5 +1,5 @@
-#include "config.h"
-#include "vm/wrappers.h"
+#include <config.h>
+#include "wrappers.h"
 
 char teaseme_digits[] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
       'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j',
@@ -10,7 +10,7 @@ int sprintInt(char* str, int value) {
 
   //print the decimal string for value
   int pos = 0;
-  int i   = 0;
+  int i;
   int radix = 10;
   //int negative = (value < 0) ? 1 : 0;
   //  int orig = value;
